summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls
diff options
context:
space:
mode:
authorxue <>2006-03-31 12:42:22 +0000
committerxue <>2006-03-31 12:42:22 +0000
commit6845c00a3f752abecd9ef763848329bceaf63df4 (patch)
treed573c37ad864edde9a04f1c7b415afe6c2a9c1ef /framework/Web/UI/WebControls
parent06fdd252452217716b1062b632fd2fc2195a66e2 (diff)
Reorganized folders under framework. This may break existing applications.
Diffstat (limited to 'framework/Web/UI/WebControls')
-rw-r--r--framework/Web/UI/WebControls/TBaseDataList.php3
-rw-r--r--framework/Web/UI/WebControls/TCompareValidator.php2
-rw-r--r--framework/Web/UI/WebControls/TDataGridColumn.php5
-rw-r--r--framework/Web/UI/WebControls/TDataTypeValidator.php2
-rw-r--r--framework/Web/UI/WebControls/TDatePicker.php12
-rw-r--r--framework/Web/UI/WebControls/TListControl.php4
-rw-r--r--framework/Web/UI/WebControls/TRangeValidator.php2
-rw-r--r--framework/Web/UI/WebControls/TWizard.php1
8 files changed, 21 insertions, 10 deletions
diff --git a/framework/Web/UI/WebControls/TCompareValidator.php b/framework/Web/UI/WebControls/TCompareValidator.php
index 811ca50a..1bf4c529 100644
--- a/framework/Web/UI/WebControls/TCompareValidator.php
+++ b/framework/Web/UI/WebControls/TCompareValidator.php
@@ -201,7 +201,7 @@ class TCompareValidator extends TBaseValidator
$dateFormat = $this->getDateFormat();
if($dateFormat!=='')
{
- $formatter = Prado::createComponent('System.Data.TSimpleDateFormatter', $dateFormat);
+ $formatter = Prado::createComponent('System.Util.TSimpleDateFormatter', $dateFormat);
return array($formatter->parse($value1), $formatter->parse($value2));
}
else
diff --git a/framework/Web/UI/WebControls/TDataGridColumn.php b/framework/Web/UI/WebControls/TDataGridColumn.php
index e8cc81aa..de9d9d5c 100644
--- a/framework/Web/UI/WebControls/TDataGridColumn.php
+++ b/framework/Web/UI/WebControls/TDataGridColumn.php
@@ -11,6 +11,11 @@
*/
/**
+ * Includes TDataFieldAccessor class
+ */
+Prado::using('System.Util.TDataFieldAccessor');
+
+/**
* TDataGridColumn class
*
* TDataGridColumn serves as the base class for the different column types of
diff --git a/framework/Web/UI/WebControls/TDataTypeValidator.php b/framework/Web/UI/WebControls/TDataTypeValidator.php
index f3cf5a3c..81c23ce4 100644
--- a/framework/Web/UI/WebControls/TDataTypeValidator.php
+++ b/framework/Web/UI/WebControls/TDataTypeValidator.php
@@ -91,7 +91,7 @@ class TDataTypeValidator extends TBaseValidator
$dateFormat = $this->getDateFormat();
if(strlen($dateFormat))
{
- $formatter = Prado::createComponent('System.Data.TSimpleDateFormatter',$dateFormat);
+ $formatter = Prado::createComponent('System.Util.TSimpleDateFormatter',$dateFormat);
return $formatter->isValidDate($value);
}
else
diff --git a/framework/Web/UI/WebControls/TDatePicker.php b/framework/Web/UI/WebControls/TDatePicker.php
index 8d6d45e4..0d30636c 100644
--- a/framework/Web/UI/WebControls/TDatePicker.php
+++ b/framework/Web/UI/WebControls/TDatePicker.php
@@ -256,7 +256,7 @@ class TDatePicker extends TTextBox
public function setDate($value)
{
$date = TPropertyValue::ensureInteger($value);
- $formatter = Prado::createComponent('System.Data.TSimpleDateFormatter',
+ $formatter = Prado::createComponent('System.Util.TSimpleDateFormatter',
$this->getDateFormat());
$this->setText($formatter->format($date));
}
@@ -358,7 +358,7 @@ class TDatePicker extends TTextBox
$date = @mktime(0, 0, 0, $month, $day, $year);
$pattern = $this->getDateFormat();
$pattern = str_replace(array('MMMM', 'MMM'), array('MM','MM'), $pattern);
- $formatter = Prado::createComponent('System.Data.TSimpleDateFormatter', $pattern);
+ $formatter = Prado::createComponent('System.Util.TSimpleDateFormatter', $pattern);
return $formatter->format($date);
}
@@ -452,7 +452,7 @@ class TDatePicker extends TTextBox
protected function hasDayPattern()
{
- $formatter = Prado::createComponent('System.Data.TSimpleDateFormatter',
+ $formatter = Prado::createComponent('System.Util.TSimpleDateFormatter',
$this->getDateFormat());
return !is_null($formatter->getDayPattern());
}
@@ -464,7 +464,7 @@ class TDatePicker extends TTextBox
*/
protected function renderCalendarSelections($writer, $date)
{
- $formatter = Prado::createComponent('System.Data.TSimpleDateFormatter',
+ $formatter = Prado::createComponent('System.Util.TSimpleDateFormatter',
$this->getDateFormat());
foreach($formatter->getDayMonthYearOrdering() as $type)
{
@@ -485,7 +485,7 @@ class TDatePicker extends TTextBox
{
$pattern = $this->getDateFormat();
$pattern = str_replace(array('MMMM', 'MMM'), array('MM','MM'), $pattern);
- $formatter = Prado::createComponent('System.Data.TSimpleDateFormatter',$pattern);
+ $formatter = Prado::createComponent('System.Util.TSimpleDateFormatter',$pattern);
return $formatter->parse($this->getText());
}
@@ -550,7 +550,7 @@ class TDatePicker extends TTextBox
*/
protected function getLocalizedMonthNames($info)
{
- $formatter = Prado::createComponent('System.Data.TSimpleDateFormatter',
+ $formatter = Prado::createComponent('System.Util.TSimpleDateFormatter',
$this->getDateFormat());
switch($formatter->getMonthPattern())
{
diff --git a/framework/Web/UI/WebControls/TListControl.php b/framework/Web/UI/WebControls/TListControl.php
index 3d73556a..ccbce4d6 100644
--- a/framework/Web/UI/WebControls/TListControl.php
+++ b/framework/Web/UI/WebControls/TListControl.php
@@ -18,6 +18,10 @@ Prado::using('System.Web.UI.WebControls.TDataBoundControl');
* Includes TAttributeCollection class
*/
Prado::using('System.Collections.TAttributeCollection');
+/**
+ * Includes TDataFieldAccessor class
+ */
+Prado::using('System.Util.TDataFieldAccessor');
/**
* TListControl class
diff --git a/framework/Web/UI/WebControls/TRangeValidator.php b/framework/Web/UI/WebControls/TRangeValidator.php
index 842797ba..7ded3e71 100644
--- a/framework/Web/UI/WebControls/TRangeValidator.php
+++ b/framework/Web/UI/WebControls/TRangeValidator.php
@@ -226,7 +226,7 @@ class TRangeValidator extends TBaseValidator
$dateFormat = $this->getDateFormat();
if($dateFormat!=='')
{
- $formatter=Prado::createComponent('System.Data.TSimpleDateFormatter', $dateFormat);
+ $formatter=Prado::createComponent('System.Util.TSimpleDateFormatter', $dateFormat);
$value = $formatter->parse($value, $dateFormat);
if($minValue!=='')
$valid=$valid && ($value>=$formatter->parse($minValue));
diff --git a/framework/Web/UI/WebControls/TWizard.php b/framework/Web/UI/WebControls/TWizard.php
index 0b44872b..ef4691bd 100644
--- a/framework/Web/UI/WebControls/TWizard.php
+++ b/framework/Web/UI/WebControls/TWizard.php
@@ -16,6 +16,7 @@ Prado::using('System.Web.UI.WebControls.TButton');
Prado::using('System.Web.UI.WebControls.TLinkButton');
Prado::using('System.Web.UI.WebControls.TImageButton');
Prado::using('System.Web.UI.WebControls.TDataList');
+Prado::using('System.Collections.TStack');
/**
* Class TWizard.
diff --git a/framework/Web/UI/WebControls/TBaseDataList.php b/framework/Web/UI/WebControls/TBaseDataList.php
index b7c79cbe..479fb2ef 100644
--- a/framework/Web/UI/WebControls/TBaseDataList.php
+++ b/framework/Web/UI/WebControls/TBaseDataList.php
@@ -11,9 +11,10 @@
*/
/**
* Includes TDataBoundControl class
*/
Prado::using('System.Web.UI.WebControls.TDataBoundControl');
+Prado::using('System.Util.TDataFieldAccessor');
/**
* TBaseDataList class
@@ -11,9 +11,10 @@
*/
/**
- * Includes TDataBoundControl class
+ * Includes TDataBoundControl and TDataFieldAccessor classes
*/
Prado::using('System.Web.UI.WebControls.TDataBoundControl');